.. warning::
    Client version 2 is obsolete, please use Client version 3 instead.


Client initialization
=====================

To create client instance use either of two functions:
    - :py:meth:`copr.create_client2_from_params`
    - :py:meth:`copr.create_client2_from_file_config`

Config file should be generated by the Copr service itself (`Api info page`_). Don't forget to login.





.. _`Api info page`: https://copr.fedoraproject.org/api/
